@@ -6,11 +6,11 @@ from gi.repository import Gtk, GLib
 from auto_cpufreq.gui.app import ToolWindow
 
 def main():
-    GLib.set_prgname("auto-cpufreq")
+    GLib.set_prgname("auto-cpufreq-gtk")
     win = ToolWindow()
     win.connect("destroy", Gtk.main_quit)
     win.show_all()
     win.handle_update()
     Gtk.main()
 
-if __name__ == "__main__": main()
\ No newline at end of file
+if __name__ == "__main__": main()
